ObsPy Documentation (|release|)
===============================

.. image:: _static/obspy_logo_full.svg
    :alt: ObsPy logo
    :class: banner

ObsPy is an open-source project dedicated to provide a **Python framework for
processing seismological data**. It provides parsers for common file formats,
clients to access data centers and seismological signal processing routines
which allow the manipulation of seismological time series (see
[Beyreuther2010]_, [Megies2011]_, [Krischer2015]_).

The goal of the ObsPy project is to facilitate **rapid application development
for seismology**.

.. raw:: html

    <div class="startpage">


Getting Started
---------------

.. hlist::

    * `Tutorial <tutorial/index.html>`_

      *Start here*

    * `API Overview <packages/index.html>`_

      Use the source, Luke

    * `Announcements Mailing List <https://mail.python.org/mailman3/lists/obspy.python.org/>`_
      /
      `User Forum <https://discourse.obspy.org/>`_

      *Stay informed*

    * `Gallery <gallery.html>`_

      *Eye candy*

    * `FAQs on GitHub <https://github.com/obspy/obspy/issues?q=label%3Aquestion>`_
      /
      `Search Forum <https://discourse.obspy.org/>`_

      *Frequently asked questions*

    * `Help! <https://github.com/obspy/obspy/issues/new>`_

      *Report bugs, suggest features or submit patches*


Developer Resources
-------------------

.. hlist::

    * `Contributing <contributing.html>`_

      *Give back to the community*

    * `Buildbot <https://tests.obspy.org/>`_

      *Latest test reports*

    * `Coding Style Guide <coding_style.html>`_

      *It's all about consistency*

    * `Changelog <changelog.html>`_

      *Records of changes such as bug fixes, new features, etc.*


Indices and Tables
------------------

.. hlist::

    * `Table of Contents <contents.html>`_

      *Lists all sections and subsections*

    * `Python Module Index <py-modindex.html>`_

      *Quick access to all modules*

    * `Index <genindex.html>`_

      *All functions, classes, terms*

    * `Citations <citations.html>`_ / `Credits <credits.html>`_

      *Lists of contributors and used publications*


.. raw:: html

    </div>



.. toctree::
    :hidden:
    :glob:
    :maxdepth: 2
    :caption: Getting Started

    tutorial/index
    gallery
    packages/index


.. toctree::
    :hidden:
    :glob:
    :maxdepth: 2
    :caption: Developer Resources

    contributing
    coding_style
    code_of_conduct
    changelog


.. toctree::
    :hidden:
    :glob:
    :maxdepth: 2
    :caption: Indices and Tables

    contents
    `Index <genindex.html>`_
    `Python Module Index <py-modindex.html>`_
    citations
    credits
